summaryrefslogtreecommitdiff
path: root/src/mm-iface-modem.h
diff options
context:
space:
mode:
authorAleksander Morgado <aleksander@lanedo.com>2013-05-24 12:35:44 +0200
committerAleksander Morgado <aleksander@lanedo.com>2013-06-05 19:15:15 +0200
commit700ebc5c07ce667204f95dbe61716234131c15fb (patch)
treeb31f281dbcd072cbb360847f858e0eda5af67a8f /src/mm-iface-modem.h
parent1c67d050cb0451a63c8fdb0bd673892bdc04e4e0 (diff)
downloadModemManager-700ebc5c07ce667204f95dbe61716234131c15fb.tar.gz
api,introspection: rename 'ModemCapabilities' to 'SupportedCapabilities'
And also make it a list of masks, specifying which are the specific combinations supported, not just one mask with all. E.g.: ------------------------- Hardware | manufacturer: 'Sierra Wireless, Incorporated' | model: 'MC7710' | revision: 'SWI9200X_03.05.19.04ap r5475 carmd-en-10527 2012/09/17 17:57:14' | supported: 'gsm-umts | gsm-umts, lte' | current: 'gsm-umts, lte' | equipment id: '358178040668164'
Diffstat (limited to 'src/mm-iface-modem.h')
-rw-r--r--src/mm-iface-modem.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/mm-iface-modem.h b/src/mm-iface-modem.h
index 8ba1da668..8f87bc6ba 100644
--- a/src/mm-iface-modem.h
+++ b/src/mm-iface-modem.h
@@ -42,13 +42,13 @@ typedef struct _MMIfaceModem MMIfaceModem;
struct _MMIfaceModem {
GTypeInterface g_iface;
- /* Loading of the ModemCapabilities property */
- void (*load_modem_capabilities) (MMIfaceModem *self,
- GAsyncReadyCallback callback,
- gpointer user_data);
- MMModemCapability (*load_modem_capabilities_finish) (MMIfaceModem *self,
- GAsyncResult *res,
- GError **error);
+ /* Loading of the SupportedCapabilities property */
+ void (*load_supported_capabilities) (MMIfaceModem *self,
+ GAsyncReadyCallback callback,
+ gpointer user_data);
+ GArray * (*load_supported_capabilities_finish) (MMIfaceModem *self,
+ GAsyncResult *res,
+ GError **error);
/* Loading of the CurrentCapabilities property */
void (*load_current_capabilities) (MMIfaceModem *self,